@@ -183,16 +183,20 @@ class AnymailBaseBackend(BaseEmailBackend):
             # Error if *all* recipients are invalid or refused
             # (This behavior parallels smtplib.SMTPRecipientsRefused from Django's SMTP EmailBackend)
             if anymail_status.status.issubset({"invalid", "rejected"}):
-                raise AnymailRecipientsRefused(email_message=message, payload=payload, response=response)
+                raise AnymailRecipientsRefused(email_message=message, payload=payload, response=response,
+                                               backend=self)
 
     @property
     def esp_name(self):
         """
         Read-only name of the ESP for this backend.
 
-        (E.g., MailgunBackend will return "Mailgun")
+        Concrete backends must override with class attr. E.g.:
+            esp_name = "Postmark"
+            esp_name = "SendGrid"  # (use ESP's preferred capitalization)
         """
-        return self.__class__.__name__.replace("Backend", "")
+        raise NotImplementedError("%s.%s must declare esp_name class attr" %
+                                  (self.__class__.__module__, self.__class__.__name__))
 
 
 class BasePayload(object):
