@@ -1,17 +1,20 @@
+import warnings
 from datetime import datetime
 
-from ..exceptions import AnymailRequestsAPIError, AnymailError
+from ..exceptions import AnymailRequestsAPIError, AnymailError, AnymailDeprecationWarning
 from ..message import AnymailRecipientStatus
 from ..utils import get_anymail_setting, rfc2822date
 
 from .base_requests import AnymailRequestsBackend, RequestsPayload
 
 
-class MailgunBackend(AnymailRequestsBackend):
+class EmailBackend(AnymailRequestsBackend):
     """
     Mailgun API Email Backend
     """
 
+    esp_name = "Mailgun"
+
     def __init__(self, **kwargs):
         """Init options from Django settings"""
         esp_name = self.esp_name
@@ -22,7 +25,7 @@ class MailgunBackend(AnymailRequestsBackend):
                                       default="https://api.mailgun.net/v3")
         if not api_url.endswith("/"):
             api_url += "/"
-        super(MailgunBackend, self).__init__(api_url, **kwargs)
+        super(EmailBackend, self).__init__(api_url, **kwargs)
 
     def build_message_payload(self, message, defaults):
         return MailgunPayload(message, defaults, self)
@@ -43,15 +46,26 @@ class MailgunBackend(AnymailRequestsBackend):
             mailgun_message = parsed_response["message"]
         except (KeyError, TypeError):
             raise AnymailRequestsAPIError("Invalid Mailgun API response format",
-                                          email_message=message, payload=payload, response=response)
+                                          email_message=message, payload=payload, response=response,
+                                          backend=self)
         if not mailgun_message.startswith("Queued"):
             raise AnymailRequestsAPIError("Unrecognized Mailgun API message '%s'" % mailgun_message,
-                                          email_message=message, payload=payload, response=response)
+                                          email_message=message, payload=payload, response=response,
+                                          backend=self)
         # Simulate a per-recipient status of "queued":
         status = AnymailRecipientStatus(message_id=message_id, status="queued")
         return {recipient.email: status for recipient in payload.all_recipients}
 
 
+# Pre-v0.8 naming (deprecated)
+class MailgunBackend(EmailBackend):
+    def __init__(self, **kwargs):
+        warnings.warn(AnymailDeprecationWarning(
+            "Please update your EMAIL_BACKEND setting to "
+            "'anymail.backends.mailgun.EmailBackend'"))
+        super(MailgunBackend, self).__init__(**kwargs)
+
+
 class MailgunPayload(RequestsPayload):
 
     def __init__(self, message, defaults, backend, *args, **kwargs):
